Football’s caste system will continue to grow as more parents say no | Dallas Morning News
Description: Twenty years from now, will we look back on photos such as the one above and wonder why in the world we considered that to be

# Football’s caste system will continue to grow as more parents say no

###### Sharon Grigsby Follow @SharonFGrigsby Email sgrigsby@dallasnews.com

Published: December 11, 2014 7:18 am
(File 2013/The Associated Press)
Brenham's Ryan Nunn (22) tackles Aledo quarterback Luke Bishop (4) during the 2013 UIL Class 4A Division II state championship game. Resarch shows that parents are increasingly opposed to their children playing football.

Twenty years from now, will we look back on photos such as the one above and wonder why in the world we considered that to be “sport”?

A new poll by Bloomberg News indicates Americans are continuing to inch in that direction.

It’s more comfortable to look past the head injury issue, especially this time of year. We have high school playoffs to cheer. And a packed college bowl schedule, exciting for everyone even if your school didn’t get into the game you thought it deserved. (Baylor and TCU fans, hope you saw our editorial on that topic.) And the NFL continues to score big by most any measure, regardless of its many missteps. (Hey, we wrote about that too.)

But new research, commissioned by Bloomberg Politics, is the latest indicator that parents are increasingly refusing to let their sons play the sport. Just last month, our own sports department produced a revealing special report on former Dallas Cowboy stars and their discomfort with their sons following in their footsteps.

Overall, the Bloomberg data shows that half of the respondents don’t want their sons playing football. What’s most eye-opening — and troubling — is that the percentage who don’t want their sons participating goes up a lot among those who are college-educated (62 percent) and who make over $100,00 (also 62 percent).

While I’ve read lots of arguments about sports being a decent vehicle for young lower-income teens to ride into a better life, I hate to think of us all enjoying a game that likely will become increasingly populated by those whose parents aren’t educated about the risks. Polls such as Bloomberg’s leave me feeling a bit like we’ve got a growing caste system in this sport.

One bright note in the survey: 58 percent of women (as opposed to 41 percent of men) oppose their sons playing football. That number includes moms of all educational and financial backgrounds.

We’re a long way from becoming a nation of flag football supporters, but I hope the momentum grows for finding ways to create a sport that is a lot less violent.

### Top Picks

Comments

To post a comment, log into your chosen social network and then add your comment below. Your comments are subject to our Terms of Service and the privacy policy and terms of service of your social network. If you do not want to comment with a social network, please consider writing a letter to the editor.

Archives
About this blog
About This Blog

The Dallas Morning News Editorial Board was the first editorial board in the nation to use a blog to openly discuss hot topics and issues among its members and with readers. Our intent is to pull back the curtain on the daily process of producing the unsigned editorials that reflect the opinion of the newspaper, and to share analysis and opinion on issues of interest to board members and invited guest bloggers.

Members of the editorial board also blog on special-interest blogs:

- Education Blog
- Transportation
- Texas Faith Blog

Ad:Right
Ad: Position1
Ad: Position2
Ad: Right2
Categories
Mobile/Newsletters
Ad: Position3
Ad: Position4